==> zio-aws-codecommit_2.13-5.17.212.1-sources.jar: zio/aws/codecommit/model/BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{
  RepositoryName,
  ApprovalRuleTemplateName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest(
    approvalRuleTemplateName: ApprovalRuleTemplateName,
    repositoryNames: Iterable[RepositoryName]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest = {
    import BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
      .builder()
      .approvalRuleTemplateName(
        ApprovalRuleTemplateName.unwrap(
          approvalRuleTemplateName
        ): java.lang.String
      )
      .repositoryNames(repositoryNames.map { item =>
        RepositoryName.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly =
    zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
      .wrap(buildAwsValue())
}
object BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest =
      zio.aws.codecommit.model
        .BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest(
          approvalRuleTemplateName,
          repositoryNames
        )
    def approvalRuleTemplateName: ApprovalRuleTemplateName
    def repositoryNames: List[RepositoryName]
    def getApprovalRuleTemplateName
        : ZIO[Any, Nothing, ApprovalRuleTemplateName] =
      ZIO.succeed(approvalRuleTemplateName)
    def getRepositoryNames: ZIO[Any, Nothing, List[RepositoryName]] =
      ZIO.succeed(repositoryNames)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ) extends zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly {
    override val approvalRuleTemplateName: ApprovalRuleTemplateName =
      zio.aws.codecommit.model.primitives
        .ApprovalRuleTemplateName(impl.approvalRuleTemplateName())
    override val repositoryNames: List[RepositoryName] = impl
      .repositoryNames()
      .asScala
      .map { item =>
        zio.aws.codecommit.model.primitives.RepositoryName(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ): zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecommit_3-5.17.130.6-sources.jar: zio/aws/codecommit/model/BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{
  RepositoryName,
  ApprovalRuleTemplateName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest(
    approvalRuleTemplateName: ApprovalRuleTemplateName,
    repositoryNames: Iterable[RepositoryName]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest = {
    import BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
      .builder()
      .approvalRuleTemplateName(
        ApprovalRuleTemplateName.unwrap(
          approvalRuleTemplateName
        ): java.lang.String
      )
      .repositoryNames(repositoryNames.map { item =>
        RepositoryName.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly =
    zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
      .wrap(buildAwsValue())
}
object BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest =
      zio.aws.codecommit.model
        .BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest(
          approvalRuleTemplateName,
          repositoryNames
        )
    def approvalRuleTemplateName: ApprovalRuleTemplateName
    def repositoryNames: List[RepositoryName]
    def getApprovalRuleTemplateName
        : ZIO[Any, Nothing, ApprovalRuleTemplateName] =
      ZIO.succeed(approvalRuleTemplateName)
    def getRepositoryNames: ZIO[Any, Nothing, List[RepositoryName]] =
      ZIO.succeed(repositoryNames)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ) extends zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly {
    override val approvalRuleTemplateName: ApprovalRuleTemplateName =
      zio.aws.codecommit.model.primitives
        .ApprovalRuleTemplateName(impl.approvalRuleTemplateName())
    override val repositoryNames: List[RepositoryName] = impl
      .repositoryNames()
      .asScala
      .map { item =>
        zio.aws.codecommit.model.primitives.RepositoryName(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest
  ): zio.aws.codecommit.model.BatchDisassociateApprovalRuleTemplateFromRepositoriesRequest.ReadOnly =
    new Wrapper(impl)
}
